#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <sisio.h>

void sisinlh5( inbuf, inlen, outbuf, outlen )

	char *	inbuf;
	int *	inlen;
	char *	outbuf;
	int *	outlen;

{
	int	start, number, length, perword, ier;

	memcpy( outbuf + 0, inbuf + 0, 48);
	memcpy( outbuf + 48, inbuf + 48, 16);
	HTOCL( outbuf + 48, 4 );
	memcpy( outbuf + 64, inbuf + 64, 6);
	HTOCS( outbuf + 64, 3 );
	memcpy( outbuf + 70, inbuf + 70, 4);
	memcpy( outbuf + 74, inbuf + 74, 2);
	HTOCS( outbuf + 74, 1 );
	memcpy( outbuf + 76, inbuf + 76, 4);
	memcpy( outbuf + 80, inbuf + 80, 4);
	HTOCL( outbuf + 80, 1 );
	memcpy( outbuf + 84, inbuf + 84, 16);
	HTOCS( outbuf + 84, 8 );
	memcpy( outbuf + 100, inbuf + 100, 4);
	memcpy( outbuf + 104, inbuf + 104, 4);
	HTOCL( outbuf + 104, 1 );
	memcpy( outbuf + 108, inbuf + 108, 4);
	HTOCS( outbuf + 108, 2 );
	memcpy( outbuf + 112, inbuf + 112, 4);
	HTOCF( outbuf + 112, 1 );
	memcpy( outbuf + 116, inbuf + 116, 4);
	HTOCS( outbuf + 116, 2 );
	memcpy( outbuf + 120, inbuf + 120, 4);
	HTOCL( outbuf + 120, 1 );
	memcpy( outbuf + 124, inbuf + 124, 26);
	HTOCS( outbuf + 124, 13 );
	memcpy( outbuf + 150, inbuf + 150, 4 );
	memcpy( outbuf + 154, inbuf + 154, 2);
	HTOCS( outbuf + 154, 1 );
	memcpy( outbuf + 156, inbuf + 156, 4);
	HTOCL( outbuf + 156, 1 );
	memcpy( outbuf + 160, inbuf + 160, 440 );
	memcpy( outbuf + 600, inbuf + 600, 400);
	HTOCS( outbuf + 600, 200 );
	*outlen = 1000;
	hlhs2in( inbuf, *inlen, 1001, outbuf, 1000000, outlen );
}
